@@ -5,14 +5,12 @@ from AsteriskCommand.commons.asterisk_command import AsteriskCommand
 
 @dataclass
 class ClearIdleCallActors(AsteriskCommand):
-    action_id: str
-    action: str = "ClearIdleCallActors"
-
-    def __init__(self) -> None:
-        self.is_asterisk_command = False
+    ActionID: str
+    Action: str = "ClearIdleCallActors"
+    is_asterisk_command: bool = False
 
     def as_dict(self) -> Dict:
         return {
-            "Action": self.action,
-            "ActionID": self.action_id,
+            "Action": self.Action,
+            "ActionID": self.ActionID,
         }
