@@ -1,13 +1,14 @@
 import json
-from abc import ABC, abstractmethod
 from typing import Dict, List
+from abc import ABC, abstractmethod
+from dataclasses import field
 from AsteriskCommand.commons.asterisk_action import Action
 
 
 class AsteriskCommand(ABC):
-    action: str
+    Action: str
     auxiliar_commands: List
-    variables: Dict = dict()
+    Variables: Dict = field(default_factory=dict)
     is_asterisk_command: bool = True
 
     @abstractmethod
@@ -18,4 +19,4 @@ class AsteriskCommand(ABC):
         return json.dumps(self.as_dict())
 
     def as_asterisk_command(self) -> Action:
-        return Action(name=self.action, keys=self.as_dict(), variables=self.variables)
+        return Action(name=self.Action, keys=self.as_dict(), variables=self.Variables)
