@@ -5,11 +5,9 @@ from AsteriskCommand.commons.asterisk_command import AsteriskCommand
 
 @dataclass
 class GetInfoAnexos(AsteriskCommand):
-    action_id: str
-    action: str = "GetInfoAnexos"
-
-    def __init__(self) -> None:
-        self.is_asterisk_command = False
+    ActionID: str
+    Action: str = "GetInfoAnexos"
+    is_asterisk_command: bool = False
 
     def as_dict(self) -> Dict:
-        return {"Action": self.action, "ActionId": self.action_id}
+        return {"Action": self.Action, "ActionID": self.ActionID}
