@@ -5,8 +5,8 @@ from AsteriskCommand.commons.asterisk_command import AsteriskCommand
 
 @dataclass
 class SIPpeers(AsteriskCommand):
-    action_id: str
-    action: str = "SIPpeers"
+    ActionID: str
+    Action: str = "SIPpeers"
 
     def as_dict(self) -> Dict:
-        return {"Action": self.action, "ActionID": self.action_id}
+        return {"Action": self.Action, "ActionID": self.ActionID}
